@@ -3,9 +3,11 @@
 package POE::Filter::RecordBlock;
 
 use strict;
+use POE::Filter;
 
-use vars qw($VERSION);
-$VERSION = do {my@r=(q$Revision: 1.4 $=~/\d+/g);sprintf"%d."."%04d"x$#r,@r};
+use vars qw($VERSION @ISA);
+$VERSION = do {my@r=(q$Revision: 1.6 $=~/\d+/g);sprintf"%d."."%04d"x$#r,@r};
+@ISA = qw(POE::Filter);
 
 use Carp qw(croak);
 
@@ -22,23 +24,20 @@ sub new {
   croak "$type must be given an even number of parameters" if @_ & 1;
   my %params = @_;
 
-  croak "BlockSize must be greater than 0" if
-    !defined($params{BlockSize}) || ($params{BlockSize} < 1);
+  croak "BlockSize must be greater than 0" unless (
+    defined($params{BlockSize}) || ($params{BlockSize} < 1)
+  );
 
-  my $self = bless [$params{BlockSize}, [], [], $params{CheckPut}], $type;
+  my $self = bless [
+    $params{BlockSize}, # BLOCKSIZE
+    [],                 # GETBUFFER
+    [],                 # PUTBUFFER
+    $params{CheckPut},  # CHECKPUT
+  ], $type;
 }
 
 #------------------------------------------------------------------------------
-
-sub get {
-  my ($self, $data) = @_;
-  my @result;
-  push @{$self->[GETBUFFER]}, @$data;
-  while (@{$self->[GETBUFFER]} >= $self->[BLOCKSIZE]) {
-    push @result, [ splice @{$self->[GETBUFFER]}, 0, $self->[BLOCKSIZE] ];
-  }
-  \@result;
-}
+# get() is inherited from POE::Filter.
 
 #------------------------------------------------------------------------------
 # 2001-07-27 RCC: Add get_one_start() and get_one() to correct filter
@@ -53,7 +52,7 @@ sub get_one {
   my $self = shift;
 
   return [ ] unless @{$self->[GETBUFFER]} >= $self->[BLOCKSIZE];
-  return [ splice @{$self->[GETBUFFER]}, 0, $self->[BLOCKSIZE] ];
+  return [ [ splice @{$self->[GETBUFFER]}, 0, $self->[BLOCKSIZE] ] ];
 }
 
 #------------------------------------------------------------------------------
