@@ -1,4 +1,4 @@
-# $Id: Event.pm,v 1.41 2004/11/16 07:54:11 teknikill Exp $
+# $Id: Event.pm,v 1.43 2005/05/15 07:09:44 rcaputo Exp $
 
 # Event.pm event loop bridge for POE::Kernel.
 
@@ -8,7 +8,7 @@ package POE::Loop::Event;
 use strict;
 
 use vars qw($VERSION);
-$VERSION = do {my@r=(q$Revision: 1.41 $=~/\d+/g);sprintf"%d."."%04d"x$#r,@r};
+$VERSION = do {my@r=(q$Revision: 1.43 $=~/\d+/g);sprintf"%d."."%04d"x$#r,@r};
 
 # Everything plugs into POE::Kernel.
 package POE::Kernel;
@@ -82,6 +82,7 @@ sub _loop_signal_handler_child {
     POE::Kernel::_warn "<sg> Enqueuing CHLD-like SIG$_[0] event";
   }
 
+  $poe_kernel->_idle_queue_grow();
   $poe_kernel->_data_ev_enqueue(
     $poe_kernel, $poe_kernel, EN_SCPOLL, ET_SCPOLL, [ ],
     __FILE__, __LINE__, undef, time(),
@@ -94,22 +95,19 @@ sub _loop_signal_handler_child {
 sub loop_watch_signal {
   my ($self, $signal) = @_;
 
-  # Child process has stopped.
+  # Child process has stopped.  We use Event's safe SIGCHLD handler.
   if ($signal eq 'CHLD' or $signal eq 'CLD') {
-
-    # Begin constant polling loop.  Only start it on CHLD or on CLD if
-    # CHLD doesn't exist.
-    $SIG{$signal} = 'DEFAULT';
-    $self->_data_ev_enqueue(
-      $self, $self, EN_SCPOLL, ET_SCPOLL, [ ],
-      __FILE__, __LINE__, undef, time() + 1,
-    ) if $signal eq 'CHLD' or not exists $SIG{CHLD};
-
+    $SIG{$signal} = "DEFAULT";
+    $signal_watcher{CHLD} = Event->signal(
+      signal => $signal,
+      cb     => \&_loop_signal_handler_child
+    );
     return;
   }
 
   # Broken pipe.
   if ($signal eq 'PIPE') {
+    $SIG{$signal} = "DEFAULT";
     $signal_watcher{$signal} = Event->signal(
       signal => $signal,
       cb     => \&_loop_signal_handler_pipe
@@ -129,10 +127,17 @@ sub loop_watch_signal {
 
 sub loop_ignore_signal {
   my ($self, $signal) = @_;
+
   if (defined $signal_watcher{$signal}) {
     $signal_watcher{$signal}->stop();
     delete $signal_watcher{$signal};
   }
+
+  # Certain kinds of signals should be ignored by default.
+  if ($signal =~ /^(CH?LD|PIPE)$/) {
+    $SIG{$signal} = "IGNORE";
+    return;
+  }
 }
 
 sub loop_attach_uidestroy {
